pub struct MllpFormatter;Implementations
Sourceimpl MllpFormatter
impl MllpFormatter
pub fn encode(payload: &[u8]) -> Vec<u8> ⓘ
Sourcepub fn decode(framed: &[u8]) -> Result<&[u8], OperationOutcomeError>
pub fn decode(framed: &[u8]) -> Result<&[u8], OperationOutcomeError>
Decodes an MLLP-framed message and returns the enclosed payload.
Errors
Returns an [OperationOutcomeError] if framed is not a valid MLLP frame,
that is, if it is shorter than the minimum frame length or does not start
with <SB> and end with <EB><CR>.
pub fn ack() -> [u8; 4]
pub fn nak() -> [u8; 4]
pub fn is_ack(bytes: &[u8]) -> bool
pub fn is_nak(bytes: &[u8]) -> bool
Sourcepub fn read_frame<R: Read>(
reader: &mut R,
) -> Result<Vec<u8>, OperationOutcomeError>
pub fn read_frame<R: Read>( reader: &mut R, ) -> Result<Vec<u8>, OperationOutcomeError>
Reads a single MLLP frame from reader, returning the raw framed bytes,
including the START_BLOCK, END_BLOCK, and CARRIAGE_RETURN
delimiters.
Errors
Returns an [OperationOutcomeError] if:
- the stream ends before a complete MLLP frame is received,
- the frame does not begin with
START_BLOCK, or - an I/O error occurs while reading from the stream.